.. image:: https://raw.githubusercontent.com/cr0hn/festin/master/images/festin-logo-banner.png

`FestIN` is a powered S3 bucket finder and content discover


Why Festin
==========

There's a lot of S3 tools, but

Diferencias:
* Implementa varias técnicas
* No necesitamos claves de AWS
* Funciona con cualquier sistema compatible con S3
* Permite configurar tor y servidores dns específicos
* Extrae los links de una web y los mete en el flujo
* es recursivo
* En modo servicio


Install
=======

.. code-block:: console

    $ pip install festin

License
=======

This project is distributed under `BSD license <https://github.com/cr0hn/festin/blob/master/LICENSE>`_


